==> oggcodecs_src_0.69.8924.zip: oggdsf/src/lib/core/ogg/libOOOgg/IFIFOBuffer.h <==
//===========================================================================
//Copyright (C) 2003, 2004 Zentaro Kavanagh
//
//Redistribution and use in source and binary forms, with or without
//modification, are permitted provided that the following conditions
//are met:
//
//- Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//- Redistributions in binary form must reproduce the above copyright
//  notice, this list of conditions and the following disclaimer in the
//  documentation and/or other materials provided with the distribution.
//
//- Neither the name of Zentaro Kavanagh nor the names of contributors 
//  may be used to endorse or promote products derived from this software 
//  without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
//PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
//CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//===========================================================================
#pragma once
#include <libOOOgg/dllstuff.h>
class LIBOOOGG_API IFIFOBuffer {
public:
	//Empty Constructor and destructor to ensure proper deletion
	IFIFOBuffer(void)				{}
	virtual ~IFIFOBuffer(void)		{}

	/// Read bytes from the internal buffer. Returns how many actually read.
	virtual unsigned long read(unsigned char* outData, unsigned long inBytesToRead) = 0;

	/// Write bytes into the internal buffer. Returns how many written.
	virtual unsigned long write(const unsigned char* inData, unsigned long inBytesToWrite) = 0;

	/// Returns how many bytes are available in the buffer.
	virtual  unsigned long numBytesAvail() = 0;

	/// Returns how much space is left in the buffer.
	virtual unsigned long spaceLeft() = 0;

	/// Resets the buffer.
	virtual void reset() = 0;
};

==> oggcodecs_src_0.70.0827.zip: oggdsf/src/lib/core/ogg/libOOOgg/IFIFOBuffer.h <==
//===========================================================================
//Copyright (C) 2003, 2004 Zentaro Kavanagh
//
//Redistribution and use in source and binary forms, with or without
//modification, are permitted provided that the following conditions
//are met:
//
//- Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//- Redistributions in binary form must reproduce the above copyright
//  notice, this list of conditions and the following disclaimer in the
//  documentation and/or other materials provided with the distribution.
//
//- Neither the name of Zentaro Kavanagh nor the names of contributors 
//  may be used to endorse or promote products derived from this software 
//  without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
//PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
//CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//===========================================================================
#pragma once
#include <libOOOgg/dllstuff.h>
class LIBOOOGG_API IFIFOBuffer {
public:
	//Empty Constructor and destructor to ensure proper deletion
	IFIFOBuffer(void)				{}
	virtual ~IFIFOBuffer(void)		{}

	/// Read bytes from the internal buffer. Returns how many actually read.
	virtual unsigned long read(unsigned char* outData, unsigned long inBytesToRead, bool inAllowShortRead = false  ) = 0;

	/// Write bytes into the internal buffer. Returns how many written.
	virtual unsigned long write(const unsigned char* inData, unsigned long inBytesToWrite) = 0;

	/// Returns how many bytes are available in the buffer.
	virtual  unsigned long numBytesAvail() = 0;

	/// Returns how much space is left in the buffer.
	virtual unsigned long spaceLeft() = 0;

	/// Resets the buffer.
	virtual void reset() = 0;
};
